@@ -72,12 +72,15 @@
 #include "rewrite/rewriteHandler.h"
 #include "storage/block.h"
 #include "storage/bufmgr.h"
+#include "storage/buffile.h"
 #include "storage/ipc.h"
 #include "storage/itemptr.h"
 #include "storage/lwlock.h"
 #include "storage/procarray.h"
 #include "tcop/tcopprot.h"
 #include "tcop/utility.h"
+#include "tsearch/ts_public.h"
+#include "tsearch/ts_utils.h"
 #include "utils/builtins.h"
 #include "utils/date.h"
 #include "utils/datetime.h"
